@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for codestar-notifications service client paginators.
 
@@ -20,9 +21,10 @@ Usage::
     list_targets_paginator: ListTargetsPaginator = client.get_paginator("list_targets")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_codestar_notifications.type_defs import (
     ListEventTypesFilterTypeDef,
     ListEventTypesResultTypeDef,
@@ -33,13 +35,12 @@ from mypy_boto3_codestar_notifications.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = ("ListEventTypesPaginator", "ListNotificationRulesPaginator", "ListTargetsPaginator")
 
 
 class ListEventTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListEventTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
+    [Paginator.ListEventTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
     """
 
     def paginate(
@@ -48,13 +49,13 @@ class ListEventTypesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListEventTypesResultTypeDef]:
         """
-        [ListEventTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
+        [ListEventTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
         """
 
 
 class ListNotificationRulesPaginator(Boto3Paginator):
     """
-    [Paginator.ListNotificationRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
+    [Paginator.ListNotificationRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
     """
 
     def paginate(
@@ -63,13 +64,13 @@ class ListNotificationRulesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListNotificationRulesResultTypeDef]:
         """
-        [ListNotificationRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
+        [ListNotificationRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
         """
 
 
 class ListTargetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
+    [Paginator.ListTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
     """
 
     def paginate(
@@ -78,5 +79,5 @@ class ListTargetsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTargetsResultTypeDef]:
         """
-        [ListTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
+        [ListTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
         """
